[![Tests Status](https://github.com/SharedShithosting/Leistungsbot/actions/workflows/pytest.yml/reports/junit/junit-badge.svg?dummy=8484744)](https://github.com/SharedShithosting/Leistungsbot/actions/workflows/pytest.yml/reports/junit/report.html)
[![Docker Image CI](https://github.com/SharedShithosting/Leistungsbot/actions/workflows/docker-image.yml/badge.svg)](https://github.com/SharedShithosting/Leistungsbot/actions/workflows/docker-image.yml)
[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/SharedShithosting/Leistungsbot/main.svg)](https://results.pre-commit.ci/latest/github/SharedShithosting/Leistungsbot/main)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)


## Intro
  <body>This Is A Simple Bot To Create Poll In Channel and Groups <br> And Also This Is our First Project Too..


## Enter you tokens at these are very important VARS:
  Without fork you cant deploy so fork it and edit in [Bot.py#L22](https://github.com/BotsUniverse/poll-bot/blob/main/Bot.py#L22)

## DEVLOPERS
😎ROHITH [ROHITHADITYA](https://telegram.me/rohithaditya) <br> 😋PARVAT [PARVAT_R](https://telegram.me/Parvat_R)

## QUICK NOTES
**DONT FORGET TO JOIN [Venila Bots](https://telegram.me/venilabots)**

## LANUGUAGES
<br>
>> PY BOT API
<br>
>> PYTHON

## SUPPORT GROUP
<a href="https://t.me/venilabots"><img src="https://img.shields.io/badge/Join-Telegram%20Channel-blue.svg?logo=telegram"></a><br>
<a href="https://t.me/venilabots1"><img src="https://img.shields.io/badge/Join-Telegram%20Group-blue.svg?logo=telegram"></a><br>

## SIMLIFIED READ ME HERE

Read Me --> [SIMPLIFIED README](https://springreen.ga/pollbot-docs)<br>
### DEPLOY
 ## DEPLOY TO HEROKU <br>
[![Deploy](https://www.herokucdn.com/deploy/button.svg)](http://springreen.ga/pollbot-docs/#getting_started)

 ## RUN IN TERMUX
```
git clone https://github.com/Botsuniverse/poll-bot
cd poll-bot
python3 Bot.py
```

 ## RUN IN PYDROID 3 <br>
    (x) Just Copy The Bot.py to pydroid and Simply Run it

 ## RUN IN YOUR LINUX VPS OR DESKTOP

```
sudo apt update
sudo apt upgrade
git clone https://github.com/Botsuniverse/poll-bot
python3 Bot.py
```

 ## RUN THIS IN WINDOWS TERMINAL

```bash
git clone https://github.com/BotsUniverse/poll-bot/
cd where_the_fuck_you_stored/poll-bot
py Bot.py
```
